import EntityFormTemplate from 'model/EntityFormTemplate';

const OPENSTACK_CLOUD_LAUNCH_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'openstack',
    entityName: 'cloud_launch_template',
    actionType: 'copy',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Instance',
        keyValueRecords: [
          {
            type: 'default', labelName: 'Name', name: 'name',
            defaultValue: 'copy_{name}', required: true
          },
          {
            type: 'textarea', labelName: 'Description', name: 'field_description',
            defaultValue: ''
          },
          {
            type: 'join', labelName: 'Flavor', name: 'field_instance_type', info: {
              entityTypeId: 'openstack_flavor',
              keyColumn: 'name',
            }, defaultValue: '', required: true
          },
          {
            type: 'boolean', labelName: 'Test only', name: 'field_test_only',
            defaultValue: false
          },
        ]
      },
      {
        type: 'panel',
        panelName: 'Image',
        keyValueRecords: [
          {
            type: 'select', labelName: 'Image ID', name: 'field_openstack_image_id',
            url: '/cloud_dashboard/openstack/{cloud_context}/cloud_launch_template/image_options',
            defaultValue: '', required: true
          },
        ]
      },
      {
        type: 'panel',
        panelName: 'Network',
        keyValueRecords: [
          {
            type: 'select', labelName: 'Availability Zone', name: 'field_os_availability_zone',
            url: '/cloud_dashboard/openstack/{cloud_context}/availability_zones',
            defaultValue: '', required: true
          },
          {
            type: 'multi-select', labelName: 'Security groups', name: 'security_groups',
            url: '/cloud_dashboard/openstack/{cloud_context}/security_group_options',
            defaultValue: ["{tryNotNull(getValue(openstack_security_group,relationship(field_openstack_security_group,drupal_internal__target_id),drupal_internal__id,name),'')}"],
            required: true
          },
          // TODO: Update defaultValue
          {
            type: 'join', labelName: 'SSH key', name: 'ssh_key', info: {
              entityTypeId: 'openstack_key_pair',
              keyColumn: 'key_pair_name',
              label: '{key_pair_name}'
            },
            defaultValue: "{tryNotNull(getValue(openstack_key_pair,relationship(field_openstack_ssh_key,drupal_internal__target_id),drupal_internal__id,key_pair_name),'')}",
            required: true
          },
          {
            type: 'select', labelName: 'Network interface', name: 'network_id',
            url: '/cloud_dashboard/openstack/{cloud_context}/network_options',
            defaultValue: "{tryNotNull(relationship(field_openstack_network,drupal_internal__target_id), '_none')}",
          },
        ]
      },
      {
        type: 'panel',
        panelName: 'Tags',
        keyValueRecords: [
          {
            type: 'key-value', labelName: 'Tags', name: 'field_tags',
            defaultValue: []
          },
        ]
      },
      {
        type: 'panel',
        panelName: 'Others',
        keyValueRecords: [
          {
            type: 'textarea', labelName: 'Revision log message', name: 'revision_log_message',
            defaultValue: ''
          },
        ]
      },
    ],
    submitButtonLabel: 'Copy'
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'cloud_launch_template',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to delete the {{name}} Cloud Launch Template?'
      },
    ],
    submitButtonLabel: 'Delete'
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'cloud_launch_template',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Instance',
        keyValueRecords: [
          {
            type: 'default', labelName: 'Name', name: 'name',
            defaultValue: '', readOnly: true, required: true
          },
          {
            type: 'textarea', labelName: 'Description', name: 'field_description',
            defaultValue: ''
          },
          {
            type: 'select', labelName: 'Flavor', name: 'field_flavor',
            url: '/cloud_dashboard/openstack/{cloud_context}/flavor_options',
            defaultValue: "{tryNotNull(relationship(field_openstack_flavor,drupal_internal__target_id), '_none')}",
            required: true
          },
          {
            type: 'boolean', labelName: 'Test only', name: 'field_test_only',
            defaultValue: false
          },
        ]
      },
      {
        type: 'panel',
        panelName: 'AMI',
        keyValueRecords: [
          {
            type: 'select', labelName: 'Image ID', name: 'field_openstack_image_id',
            url: '/cloud_dashboard/openstack/{cloud_context}/cloud_launch_template/image_options',
            defaultValue: '', required: true
          },
        ]
      },
      {
        type: 'panel',
        panelName: 'Network',
        keyValueRecords: [
          {
            type: 'select', labelName: 'Availability Zone', name: 'field_os_availability_zone',
            url: '/cloud_dashboard/openstack/{cloud_context}/availability_zones',
            defaultValue: '', required: true
          },
          {
            type: 'multi-select', labelName: 'Security groups', name: 'security_groups',
            url: '/cloud_dashboard/openstack/{cloud_context}/security_group_options',
            defaultValue: ["{tryNotNull(getValue(openstack_security_group,relationship(field_openstack_security_group,drupal_internal__target_id),drupal_internal__id,drupal_internal__id),'')}"],
            required: true
          },
          {
            type: 'select', labelName: 'SSH key', name: 'ssh_key',
            url: '/cloud_dashboard/openstack/{cloud_context}/key_pair_options',
            defaultValue: "{tryNotNull(relationship(field_openstack_ssh_key,drupal_internal__target_id), '_none')}",
            required: true
          },
          {
            type: 'select', labelName: 'Network interface', name: 'network_id',
            url: '/cloud_dashboard/openstack/{cloud_context}/network_options',
            defaultValue: "{tryNotNull(relationship(field_openstack_network,drupal_internal__target_id), '_none')}",
          },
        ]
      },
      {
        type: 'panel',
        panelName: 'Server group',
        keyValueRecords: [
          {
            type: 'select', labelName: 'Server group name', name: 'field_openstack_server_group',
            url: '/cloud_dashboard/openstack/{cloud_context}/server_group_options',
            defaultValue: "{tryNotNull(relationship(field_openstack_server_group,drupal_internal__target_id), '_none')}",
          },
        ]
      },
      {
        type: 'panel',
        panelName: 'Tags',
        keyValueRecords: [
          {
            type: 'key-value', labelName: 'Tags', name: 'field_tags',
            defaultValue: []
          },
        ]
      },
      {
        type: 'panel',
        panelName: 'Others',
        keyValueRecords: [
          {
            type: 'textarea', labelName: 'Revision log message', name: 'revision_log_message',
            defaultValue: ''
          },
        ]
      },
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'cloud_launch_template',
    actionType: 'review',
    entityRecords: [
      {
        type: 'label',
        text: 'Workflow status will be changed from Draft to Review.'
      },
    ],
    submitButtonLabel: 'Review'
  },
]

export default OPENSTACK_CLOUD_LAUNCH_TEMPLATE;
