import { Form } from 'react-bootstrap';

const VerticalRadioSelectBlock = ({ label, value, setValue, valueList, required, readOnly }: {
  label: string,
  value: string,
  setValue: (s: string) => void,
  valueList: { labelName: string, name: string }[],
  required: boolean,
  readOnly: boolean,
}) => {

  return <Form.Group className="form-item js-form-item">
    <Form.Label className={required ? 'form-required' : ''}>{label}</Form.Label>
    <div className="form-radios">
      {
        valueList.map((valueRecord) => {
          return <div className="form-item js-form-item form-type-radio" key={valueRecord.name}>
            <input className="form-radio" name={valueRecord.name} type="radio" value={valueRecord.name}
              checked={value === valueRecord.name}
              onChange={() => {
                setValue(valueRecord.name);
              }} readOnly={readOnly} />
            <Form.Label className="option" onClick={() => {
              setValue(valueRecord.name);
            }}>{valueRecord.labelName}</Form.Label>
          </div>;
        })
      }
    </div>
  </Form.Group>;

}

const HorizontalRadioSelectBlock = ({ label, value, setValue, valueList, required, readOnly }: {
  label: string,
  value: string,
  setValue: (s: string) => void,
  valueList: { labelName: string, name: string }[],
  required: boolean,
  readOnly: boolean,
}) => {

  return <div className="container-inline">
    <b className={required ? 'form-required' : ''}>{`${label}: `}</b>
    <div className="form-radios">
      {
        valueList.map((valueRecord) => {
          return <div className="form-item js-form-item form-type-radio" key={valueRecord.name}>
            <input className="form-radio" name={valueRecord.name} type="radio" value={valueRecord.name}
              checked={value === valueRecord.name}
              onChange={() => {
                setValue(valueRecord.name);
              }} readOnly={readOnly} />
            <Form.Label className="control-label option" onClick={() => {
              setValue(valueRecord.name);
            }}>
              {valueRecord.labelName}
            </Form.Label>
          </div>;
        })
      }
    </div>
  </div>;

}

/**
 * Block of key-value input view.
 *
 * @param
 */
const RadioSelectBlock = ({ label, value, setValue, valueList, orientation, required, readOnly }: {
  label: string,
  value: string,
  setValue: (s: string) => void,
  valueList: { labelName: string, name: string }[],
  orientation: 'horizontal' | 'vertical',
  required: boolean,
  readOnly: boolean,
}) => {

  switch (orientation) {
    case 'vertical':
      return <VerticalRadioSelectBlock
        label={label}
        value={value}
        setValue={setValue}
        valueList={valueList}
        required={required}
        readOnly={readOnly} />;
    case 'horizontal':
      return <HorizontalRadioSelectBlock
        label={label}
        value={value}
        setValue={setValue}
        valueList={valueList}
        required={required}
        readOnly={readOnly} />;
  }

}

export default RadioSelectBlock;
