@minimal @ci_job
Feature: Create and copy a launch template for OpenStack as an "authenticated user"

  @api
  Scenario: Create a launch template
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/design/server_template/{{ cloud_context }}/openstack/add"
    And I should see the heading "Add OpenStack"
    And I enter "{{ launch_template_name }}" for "Name"
    And I enter "{{ description }}" for "Description"
    And I select "{{ instance_flavor }}" from "Flavor"
    And I select "{{ image_name }}" from "Image ID"
    And I select "{{ availability_zone }}" from "Availability Zone"
    And I select "{{ security_group_name }}" from "Security groups"
    And I select "{{ key_pair_name }}" from "SSH key"
    And I select "{{ network_name }}" from "Network"
    And I press "Save"
    Then the url should match "/clouds/design/server_template/{{ cloud_context }}/"
    And I should see the success message "has been created"
    And I should see neither error nor warning messages
    And I should see the heading "{{ launch_template_name }}"

  @api
  Scenario: View the created launch template and its author
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/design/server_template/{{ cloud_context }}"
    And I should see the link "{{ launch_template_name }}"
    And I click "{{ launch_template_name }}"
    Then the url should match "/clouds/design/server_template/{{ cloud_context }}/"
    And I should see the heading "{{ launch_template_name }}"
    And I should see "{{ description }}"
    And I should see "{{ instance_flavor }}" in the "Flavor"
    And I should not see "{{ instance_flavor_as_first_option }}"
    And I should see "{{ image_name }}" in the "Image ID"
    And I should see "{{ availability_zone }}" in the "Availability Zone"
    And I should see "{{ security_group_name }}" in the "Security group"
    And I should see "{{ key_pair_name }}" in the "SSH key"
    # Temporarily comment out as the following field doest not show with behat.
    # And I should see "{{ network_name }}" in the "Network interface"
    And I should see "{{ drupal_user_name }}" in the "Authored by"

  @api
  Scenario: Edit the launch template
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/design/server_template/{{ cloud_context }}"
    And I should see the link "{{ launch_template_name }}"
    And I click "{{ launch_template_name }}"
    And the url should match "/clouds/design/server_template/{{ cloud_context }}/"
    And I click "Edit"
    And the url should match "/edit"
    And I should see the heading "Edit {{ launch_template_name }}"
    And I enter "{{ description_updated }}" for "Description"
    And I select "{{ instance_flavor_edit }}" from "Flavor"
    And I press "Save"
    Then the url should match "/clouds/design/server_template/{{ cloud_context }}/"
    And I should see the success message "has been updated"
    And I should see neither error nor warning messages
    And I should see the heading "{{ launch_template_name }}"
    And I should see "{{ description_updated }}"
    And I should see "{{ instance_flavor_edit }}" in the "Flavor"
    And I should see "{{ drupal_user_name }}" in the "Authored by"

  @api
  Scenario: Copy the created launch template by a Cloud administrator
    Given I am logged in as user {{ drupal_cloud_admin_name }}
    When I visit "/clouds/design/server_template/{{ cloud_context }}"
    And I should see the link "{{ launch_template_name }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ launch_template_name }}"
    And the url should match "/clouds/design/server_template/{{ cloud_context }}/"
    And I click "Copy"
    And the url should match "/copy"
    Then I should see the heading "Copy launch template"
    # No need to set the name since we expect the copy_of name is automatically set.
    And I select "{{ instance_flavor }}" from "Flavor"
    And I fill in "Authored by" with "{{ drupal_cloud_admin_name }}"
    And I press "Copy"
    Then I should see the success message "has been created"
    And I should see neither error nor warning messages
    And I should see the heading "{{ launch_template_name_copy }}"
    And I should see "{{ instance_flavor }}" in the "Flavor"
    And I should see "{{ image_name }}" in the "Image ID"
    And I should see "{{ availability_zone }}" in the "Availability Zone"
    And I should see "{{ security_group_name }}" in the "Security group"
    And I should see "{{ key_pair_name }}" in the "SSH key"
    And I should see "{{ network_name }}" in the "Network interface"
    And I should see "{{ drupal_cloud_admin_name }}" in the "Authored by"

  @api
  Scenario: Delete the copied launch template by an administrator
    Given I am logged in as a user with the "Administrator" role
    When I visit "/clouds/design/server_template/{{ cloud_context }}"
    And I click "Refresh"
    And I should see the link "{{ launch_template_name_copy }}"
    And I wait {{ wait }} milliseconds
    And I check the box in the "{{ launch_template_name_copy }}" row
    And I select "Delete launch template(s)" from "Action"
    And I press "Apply to selected items"
    Then the url should match "/clouds/design/server_template/{{ cloud_context }}/delete_multiple"
    And I should see "{{ launch_template_name_copy }}"
    And I press "Delete"
    And I should be on "/clouds/design/server_template/{{ cloud_context }}"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I wait {{ wait_deleted }} milliseconds
    And I click "Refresh"
    And I should not see the link "{{ launch_template_name_copy }}"

  @api
  Scenario: Delete the launch template
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/design/server_template/{{ cloud_context }}"
    And I click "Refresh"
    And I should see the link "{{ launch_template_name }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ launch_template_name }}"
    And the url should match "/clouds/design/server_template/{{ cloud_context }}/"
    And I click "Delete"
    Then the url should match "/delete"
    And I press "Delete"
    And I should be on "/clouds/design/server_template/{{ cloud_context }}"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I wait {{ wait_deleted }} milliseconds
    And I click "Refresh"
    And I should not see the link "{{ launch_template_name }}"
