@minimal @ci_job
Feature: Create, associate, disassociate, and delete a floating IP for OpenStack as an "authenticated user"

  @api
  Scenario: Create an external network
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/network/add"
    And I should see the heading "Add OpenStack network"
    And I enter "{{ network_external_name_operate }}" for "Name"
    And I check the box "External network"
    # Temporarily comment out because of the error when selecting Availability Zone
    # And I select "{{ availability_zone }}" from "Availability Zone"
    And I press "Save"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/network"
    And I should see the success message "has been created"
    And I should see neither error nor warning messages
    And I should see the link "{{ network_external_name_operate }}" in the table

  @api
  Scenario: Create a subnet with the external network
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/subnet/add"
    And I should see the heading "Add OpenStack subnet"
    And I enter "{{ subnet_name_operate }}" for "Name"
    And I select "{{ network_external_name_operate }}" from "Network"
    And I enter "{{ network_address }}" for "CIDR"
    And I select "{{ ip_version }}" from "IP version"
    And I press "Save"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/subnet"
    And I should see the success message "has been created"
    And I should see neither error nor warning messages
    And I should see the link "{{ subnet_name_operate }}" in the table

  @api
  Scenario: Create a floating IP
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/floating_ip/add"
    And I should see the heading "Add OpenStack floating IP"
    And I enter "{{ floating_ip_name_operate }}" for "Name"
    And I select "{{ network_external_name_operate }}" from "Floating network ID"
    And I press "Save"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/floating_ip"
    And I should see the success message "has been created"
    And I should see neither error nor warning messages
    And I should see the link "{{ floating_ip_name_operate }}" in the table

  @api
  Scenario: Read the floating IP
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/floating_ip"
    And I click "Refresh"
    And I should see the link "{{ floating_ip_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ floating_ip_name_operate }}"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/floating_ip/"
    And I should see "{{ floating_ip_name_operate }}" in the "page_header"
    And I should see "{{ floating_ip_name_operate }}" in the "Name"
    And I should see "{{ drupal_user_name }}" in the "Authored by"
    And I should see neither error nor warning messages

  @api
  Scenario: Update the floating IP
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/floating_ip"
    And I click "Refresh"
    And I should see the link "{{ floating_ip_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ floating_ip_name_operate }}"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/floating_ip/"
    And I click "Edit" in the actions
    And the url should match "/edit"
    And I enter "{{ floating_ip_name_operate_updated }}" for "Name"
    And I press "Save"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/floating_ip"
    And I should see the success message "has been updated"
    And I should see neither error nor warning messages
    And I should see the link "{{ floating_ip_name_operate_updated }}" in the table
    And I should not see the link "{{ floating_ip_name_operate }}" in the table

  @api
  Scenario: Delete the floating IP
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/floating_ip"
    And I click "Refresh"
    And I should see the link "{{ floating_ip_name_operate_updated }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ floating_ip_name_operate_updated }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/floating_ip/"
    And I click "Delete" in the actions
    Then the url should match "/delete"
    And I press "Delete"
    And I should be on "/clouds/openstack/{{ cloud_context }}/floating_ip"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I click "Refresh"
    # No tables exist.
    And I should not see the link "{{ floating_ip_name_operate_updated }}"

  @api
  Scenario: Delete the subnet
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/subnet"
    And I click "Refresh"
    And I should see the link "{{ subnet_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ subnet_name_operate }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/subnet/"
    And I click "Delete" in the actions
    Then the url should match "/delete"
    And I press "Delete"
    Then I should be on "/clouds/openstack/{{ cloud_context }}/subnet"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I click "Refresh"
    And I should not see the link "{{ subnet_name_operate }}"

  @api
  Scenario: Delete the external network
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/network"
    And I click "Refresh"
    And I should see the link "{{ network_external_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ network_external_name_operate }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/network/"
    And I click "Delete" in the actions
    Then the url should match "/delete"
    And I press "Delete"
    Then I should be on "/clouds/openstack/{{ cloud_context }}/network"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I click "Refresh"
    And I should not see the link "{{ network_external_name_operate }}"
