@minimal @ci_job
Feature: Create, read, update and delete a snapshot for OpenStack as an "authenticated user"

  @api
  Scenario: Create a volume
    Given I am logged in as user "{{ drupal_user_name }}"
    # Add a volume
    When I visit "/clouds/openstack/{{ cloud_context }}/volume/add"
    And I should see the heading "Add OpenStack volume"
    And I enter "{{ volume_name_operate }}" for "Name"
    And I enter "{{ volume_size }}" for "Size (GiB)"
    And I press "Save"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/volume"
    And I should see the success message "has been created"
    And I should see neither error nor warning messages
    And I should see the link "{{ volume_name_operate }}" in the table
    And I should see the text "creating" or "available" in the "{{ volume_name_operate }}" row

  @api
  Scenario: Create a snapshot
    Given I am logged in as user "{{ drupal_user_name }}"
    # Confirm the volume is available.
    When I visit "/clouds/openstack/{{ cloud_context }}/volume"
    And I wait {{ wait }} milliseconds
    And I click "Refresh"
    And I should see "available" in the "{{ volume_name_operate }}" row
    # Add a snapshot
    And I visit "/clouds/openstack/{{ cloud_context }}/snapshot/add"
    And I should see the heading "Add OpenStack snapshot"
    And I enter "{{ snapshot_name_operate }}" for "Name"
    And I enter "{{ description }}" for "Description"
    And I select "{{ volume_name_operate }}" from "Volume ID"
    And I press "Save"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/snapshot"
    And I should see the success message "has been created"
    And I should see neither error nor warning messages
    And I should see "{{ snapshot_name_operate }}" in the table

  @api
  Scenario: Read the snapshot
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/snapshot"
    And I click "Refresh"
    And I should see the link "{{ snapshot_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ snapshot_name_operate }}"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/snapshot/"
    And I should see "{{ snapshot_name_operate }}" in the "page_header"
    And I should see "{{ description }}" in the "Description"
    And I should see "{{ volume_size }}" in the "Size"
    And I should see "{{ drupal_user_name }}" in the "Authored by"
    And I should see neither error nor warning messages

  @api
  Scenario: Update the snapshot
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/snapshot"
    And I click "Refresh"
    And I should see the link "{{ snapshot_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ snapshot_name_operate }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/snapshot/"
    And I click "Edit" in the actions
    And the url should match "/edit"
    And I enter "{{ snapshot_name_operate_updated }}" for "Name"
    And I enter "{{ description_updated }}" for "Description"
    And I press "Save"
    Then I should see "{{ snapshot_name_operate_updated }}"
    And I should see the success message "has been updated"
    And I should see neither error nor warning messages
    And I should see the link "{{ snapshot_name_operate_updated }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ snapshot_name_operate_updated }}"
    And I should see "{{ snapshot_name_operate_updated }}"
    And I should see "{{ description_updated }}"
    And I should see "{{ drupal_user_name }}" in the "Authored by"

  @api
  Scenario: Delete the snapshot
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/snapshot"
    And I click "Refresh"
    And I should see the link "{{ snapshot_name_operate_updated }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ snapshot_name_operate_updated }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/snapshot/"
    And I click "Delete" in the actions
    And the url should match "/delete"
    And I press "Delete"
    Then I should be on "/clouds/openstack/{{ cloud_context }}/snapshot"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I wait {{ wait_deleted }} milliseconds
    And I click "Refresh"
    And I should not see the link "{{ snapshot_name_operate_updated }}"

  @api
  Scenario: Delete the volume
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/volume"
    And I click "Refresh"
    And I should see the link "{{ volume_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ volume_name_operate }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/volume/"
    And I click "Delete" in the actions
    And the url should match "/delete"
    And I press "Delete"
    Then I should be on "/clouds/openstack/{{ cloud_context }}/volume"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I wait {{ wait_deleted }} milliseconds
    And I click "Refresh"
    And I should not see the link "{{ volume_name_operate }}"
