@minimal @ci_job
Feature: Create, read, update, and delete a stack for OpenStack as an "authenticated user"

  @api
  Scenario: Preview a stack
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/stack/preview"
    And I should see the heading "Preview OpenStack stack - template"
    And I select "{{ stack_template_source }}" from "Template source"
    And I fill in "Template Data" with:
    """
    description: sample heat for neutron
    heat_template_version: '2013-05-23'
    outputs:
      status:
        description: status of sample_net
        value:
          get_attr:
          - sample_net
          - status
    parameters:
      {{ stack_net_name }}:
        default: {{ stack_net_default }}
        description: Name of Sample network to be created
        type: string
      sample_net_name1:
        default: 1
        description: Name of Sample network to be created
        type: number
      sample_net_name2:
        default: ['one', "two"]
        description: Name of Sample network to be created
        type: comma_delimited_list
      sample_net_name3:
        default: {"key": "value"}
        description: Name of Sample network to be created
        type: json
      sample_net_name4:
        default: "on"
        description: Name of Sample network to be created
        type: boolean
    resources:
      {{ stack_resource_name }}:
        properties:
          name:
            get_param: sample_net_name
        type: {{ stack_resource_type }}
    """
    And I press "Next"
    And the url should match "/clouds/openstack/{{ cloud_context }}/stack/preview_extra"
    And I enter "{{ stack_name_operate }}" for "Name"
    And I press "Save"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/stack"
    And I should see the success message "has been previewed"
    And I should see the success message 'stack_name: "{{ stack_name_operate }}"'
    And I should see neither error nor warning messages

  @api
  Scenario: Create a stack
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/stack/add"
    And I should see the heading "Add OpenStack stack - template"
    And I select "{{ stack_template_source }}" from "Template source"
    And I fill in "Template Data" with:
    """
    description: sample heat for neutron
    heat_template_version: '2013-05-23'
    outputs:
      status:
        description: status of sample_net
        value:
          get_attr:
          - sample_net
          - status
    parameters:
      {{ stack_net_name }}:
        default: {{ stack_net_default }}
        description: Name of Sample network to be created
        type: string
      sample_net_name1:
        default: 1
        description: Name of Sample network to be created
        type: number
      sample_net_name2:
        default: ['one', "two"]
        description: Name of Sample network to be created
        type: comma_delimited_list
      sample_net_name3:
        default: {"key": "value"}
        description: Name of Sample network to be created
        type: json
      sample_net_name4:
        default: "on"
        description: Name of Sample network to be created
        type: boolean
    resources:
      {{ stack_resource_name }}:
        properties:
          name:
            get_param: sample_net_name
        type: {{ stack_resource_type }}
    """
    And I press "Next"
    And the url should match "/clouds/openstack/{{ cloud_context }}/stack/add_extra"
    And I enter "{{ stack_name_operate }}" for "Name"
    And I press "Save"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/stack"
    And I should see the success message "has been created"
    And I should see neither error nor warning messages
    And I should see the link "{{ stack_name_operate }}" in the table

  @api
  Scenario: Read the stack
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/stack"
    And I click "Refresh"
    And I should see the link "{{ stack_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ stack_name_operate }}"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/stack/"
    And I should see "{{ stack_name_operate }}" in the "page_header"
    And I should see "{{ stack_name_operate }}" in the "Name"
    And I should see "{{ drupal_user_name }}" in the "Authored by"
    And I should see neither error nor warning messages

  @api
  Scenario: Read the resource types
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/stack"
    And I click "Refresh"
    And I should see the link "{{ stack_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ stack_name_operate }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/stack/"
    And I should see "{{ stack_name_operate }}" in the "page_header"
    And I click "Resources" in the "nav_tabs"
    Then the url should match "/resource"
    And I should see "OpenStack stack resources" in the "page_header"
    And I should see "{{ stack_resource_name }}" in the table
    And I should see "Resource ID" in the table
    And I should see "{{ stack_resource_type }}" in the "{{ stack_resource_name }}" row
    # the status should be either "CREATE_IN_PROGRESS" or "CREATE_COMPLETE"
    And I should see "CREATE" in the "{{ stack_resource_name }}" row
    # the status reason varies based on the status
    And I should see "Status Reason" in the table
    And I click "{{ stack_resource_name }}"
    Then the url should match "/resource/"
    And I should see "{{ stack_resource_name }}" in the "page_header"
    And I should see "{{ stack_resource_name }}" in the "Name"
    And I should see "{{ stack_resource_type }}" in the "Resource Type"
    And I should see "{{ drupal_user_name }}" in the "Authored by"

  @api
  Scenario: Read the events
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/stack"
    And I click "Refresh"
    And I should see the link "{{ stack_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ stack_name_operate }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/stack/"
    And I should see "{{ stack_name_operate }}" in the "page_header"
    And I click "Events" in the "nav_tabs"
    Then the url should match "/event"
    And I should see "OpenStack stack events" in the "page_header"
    And I should see "{{ stack_name_operate }}" in the table
    # The status should be either "CREATE_COMPLETE" or "CREATE_IN_PROGRESS"
    And I should see "CREATE" in the "{{ stack_resource_name }}" row
    And I should see "{{ stack_resource_name }}" in the table
    And I should see "CREATE" in the "{{ stack_resource_name }}" row

  @api
  Scenario: Update the stack
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/stack"
    And I click "Refresh"
    And I should see the link "{{ stack_name_operate }}"
    And I should see "CREATE_COMPLETE" in the "{{ stack_name_operate }}" row
    And I wait {{ wait }} milliseconds
    And I click "{{ stack_name_operate }}"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/stack/"
    And I click "Edit" in the actions
    And the url should match "/edit"
    And I select "{{ stack_template_source }}" from "Template source"
    And I fill in "Template Data" with:
    """
    description: sample heat for neutron
    heat_template_version: '2013-05-23'
    outputs:
      status:
        description: status of sample_net
        value:
          get_attr:
          - sample_net
          - status
    parameters:
      {{ stack_net_name }}:
        default: {{ stack_net_default }}
        description: Name of Sample network to be created
        type: string
      sample_net_name1:
        default: 1
        description: Name of Sample network to be created
        type: number
      sample_net_name2:
        default: ['one', "two"]
        description: Name of Sample network to be created
        type: comma_delimited_list
      sample_net_name3:
        default: {"key": "value"}
        description: Name of Sample network to be created
        type: json
      sample_net_name4:
        default: "on"
        description: Name of Sample network to be created
        type: boolean
    resources:
      {{ stack_resource_name }}:
        properties:
          name:
            get_param: sample_net_name
        type: {{ stack_resource_type }}
    """
    And I press "Next"
    And the url should match "/edit_extra"
    And I should see "{{ stack_name_operate }}"
    And I enter "{{ stack_net_default_updated }}" for "{{ stack_net_name }}"
    And I press "Save"
    Then I should see the success message "has been updated"
    And I should see neither error nor warning messages
    And I click "Refresh"
    And I should see "UPDATE_COMPLETE" in the "{{ stack_name_operate }}" row

  @api
  Scenario: Check the stack
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/stack"
    And I click "Refresh"
    And I should see the link "{{ stack_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ stack_name_operate }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/stack/"
    And I should see "{{ stack_name_operate }}" in the "page_header"
    And I click "Check" in the actions
    And the url should match "/check"
    And I press "Check"
    Then I should see the success message "has been checked"
    And I should see neither error nor warning messages
    And I should see "CHECK_COMPLETE" in the "{{ stack_name_operate }}" row

  @api
  Scenario: Suspend the stack
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/stack"
    And I click "Refresh"
    And I should see the link "{{ stack_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ stack_name_operate }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/stack/"
    And I should see "{{ stack_name_operate }}" in the "page_header"
    And I click "Suspend" in the actions
    And the url should match "/suspend"
    And I press "Suspend"
    Then I should see the success message "has been suspended"
    And I should see neither error nor warning messages
    And I wait {{ wait_resumed }} milliseconds
    And I click "Refresh"
    And I should see "SUSPEND_COMPLETE" in the "{{ stack_name_operate }}" row

  @api
  Scenario: Resume the stack
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/stack"
    And I click "Refresh"
    And I should see the link "{{ stack_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ stack_name_operate }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/stack/"
    And I should see "{{ stack_name_operate }}" in the "page_header"
    And I click "Resume" in the actions
    And the url should match "/resume"
    And I press "Resume"
    Then I should see the success message "has been resumed"
    And I should see neither error nor warning messages
    And I wait {{ wait_resumed }} milliseconds
    And I click "Refresh"
    And I should see "RESUME_COMPLETE" in the "{{ stack_name_operate }}" row

  @api
  Scenario: Delete the stack
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/stack"
    And I click "Refresh"
    And I should see the link "{{ stack_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ stack_name_operate }}"
    And the url should match "/clouds/openstack/{{ cloud_context }}/stack/"
    And I click "Delete" in the actions
    Then the url should match "/delete"
    And I press "Delete"
    And I should be on "/clouds/openstack/{{ cloud_context }}/stack"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I click "Refresh"
    # No tables exist.
    And I should not see the link "{{ stack_name_operate }}"
