<?php

namespace Drupal\cloud\Traits;

/**
 * The trait for Cloud Form.
 */
trait CloudFormTrait {

  /**
   * Update views pager options.
   *
   * @param string $module
   *   The module name.
   * @param array $views_settings
   *   The key and value array of views pager options.
   */
  protected function updateViewsPagerOptions($module, array $views_settings): void {
    // This is a trait, so we cannot use DI (dependency injection) here, so that
    // we use \Drupal::service('extension.path.resolver').
    $config_path = \Drupal::service('extension.path.resolver')->getPath('module', $module) . '/config/install';

    $views = [];
    $files = scandir($config_path);
    foreach ($files as $file) {
      if (preg_match('/^(views\.view\..+)\.yml$/', $file, $matches)) {
        $views[] = $matches[1];
      }
    }

    $options = [];
    foreach ($views_settings ?: [] as $key => $value) {
      $view_key = str_replace("{$module}_view_", '', $key);
      if (strpos($view_key, 'expose_') !== FALSE) {
        $view_key = str_replace('expose_', 'expose.', $view_key);
        if ($value) {
          $items_per_page = cloud_get_views_items_options();
          $options['display.default.display_options.pager.options.expose.items_per_page_options'] = implode(',', $items_per_page);
          $options['display.default.display_options.pager.options.expose.items_per_page_options_all'] = TRUE;
        }
      }
      $options["display.default.display_options.pager.options.$view_key"] = $value;

    }
    foreach ($views ?: [] as $view_name) {
      \Drupal::service('cloud')->updateViewsConfiguration($view_name, $options);
    }
  }

}
